"""Active device redis model."""

from datetime import datetime, timezone
from typing import Literal
from uuid import UUID

from pydantic import BaseModel, Field


class ActiveDevice(BaseModel):
    """Active device schema."""

    user_id: UUID
    client_id: str
    device_id: str
    mode: Literal["player-mode", "controller-mode", "force-player-mode"]
    connected_at: datetime | str = Field(
        default_factory=lambda: datetime.now(timezone.utc).isoformat()
    )


__all__ = ["ActiveDevice"]



import uuid
from typing import List

from sqlalchemy import ForeignKey
from sqlalchemy.orm import Mapped, mapped_column, relationship
from sqlalchemy.ext.declarative import declared_attr

from artemis_model.base import CustomSyncBase, TimeStampMixin, AuditMixin, CustomBase


class ApprovedPlaylistListMixin(TimeStampMixin, AuditMixin):
    id: Mapped[int] = mapped_column(autoincrement=True, primary_key=True, index=True)
    name: Mapped[str] = mapped_column(nullable=False)
    organization_id: Mapped[uuid.UUID] = mapped_column(
        ForeignKey("organization.id"), nullable=False, index=True
    )

    @declared_attr
    def organization(cls) -> Mapped["Organization"]:
        return relationship("Organization", back_populates="approved_playlist_lists")

    @declared_attr
    def playlist_associations(cls) -> Mapped[List["ApprovedPlaylistListPlaylistAssoc"]]:
        return relationship(cascade="all, delete-orphan")

    @declared_attr
    def playlists(cls) -> Mapped[List["Playlist"]]:
        return relationship(
            "Playlist", secondary="approved_playlist_list_playlist_assoc", viewonly=True
        )


class ApprovedPlaylistListSync(CustomSyncBase, ApprovedPlaylistListMixin):
    pass


class ApprovedPlaylistList(CustomBase, ApprovedPlaylistListMixin):
    pass


class ApprovedPlaylistListPlaylistAssocMixin(TimeStampMixin):
    approved_playlist_list_id: Mapped[int] = mapped_column(
        ForeignKey("approved_playlist_list.id"), primary_key=True, nullable=False
    )
    playlist_id: Mapped[int] = mapped_column(
        ForeignKey("playlist.id"), primary_key=True, nullable=False
    )


class ApprovedPlaylistListPlaylistAssocSync(CustomSyncBase, ApprovedPlaylistListPlaylistAssocMixin):
    pass


class ApprovedPlaylistListPlaylistAssoc(CustomBase, ApprovedPlaylistListPlaylistAssocMixin):
    pass



from artemis_model.album import *  # noqa
from artemis_model.approved_playlist_list import *  # noqa
from artemis_model.artist import *  # noqa
from artemis_model.auth import *  # noqa
from artemis_model.category import *  # noqa
from artemis_model.dj_set import *  # noqa
from artemis_model.genre import *  # noqa
from artemis_model.location import *  # noqa
from artemis_model.location_genre_exclusion import *  # noqa
from artemis_model.message import *  # noqa
from artemis_model.organization import *  # noqa
from artemis_model.organization_include_pal_setting import *  # noqa
from artemis_model.playlist import *  # noqa
from artemis_model.schedule import *  # noqa
from artemis_model.setting import *  # noqa
from artemis_model.track import *  # noqa
from artemis_model.user import *  # noqa
from artemis_model.zone import *  # noqa
from artemis_model.otp import *  # noqa
from artemis_model.banned_tracks import *  # noqa
from artemis_model.zone_activity import *  # noqa
from artemis_model.zone_state import *  # noqa
from artemis_model.billing import *  # noqa